from distutils.core import setup

setup(name="zetanize",
      packages=["zetanize"],
      version="0.9",
      description="HTML form parser for humans.",
      long_description="HTML form parser for humans.",
      author_email="s0md3v@gmail.com",
      author="Somdev Sangwan",
      url="https://github.com/s0md3v/Zetanize",
      keywords="zetanize, mechanize, html form submit, d3v",
      classifiers=['Development Status :: 5 - Production/Stable',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: MIT License',
                   'Programming Language :: Python :: 2.4',
                   'Programming Language :: Python :: 2.5',
                   'Programming Language :: Python :: 2.6',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.2',
                   'Programming Language :: Python :: 3.3',
                   'Programming Language :: Python :: 3.4',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6'],
      license="GPL-3.0",
      python_requires='>=2.4',
      )
